/* This file is part of Om.  Copyright (C) 2005 Dave Robillard.
 * 
 * Om is free software; you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 * 
 * Om is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "Event.h"
#include "Om.h"
#include "OmApp.h"
#include "JackDriver.h"

namespace Om {

// FIXME: this file should go away, but there's a circular include
// issue.  Any latency whatsoever in getting the timestamp is bad
// bad bad

Event::Event(Request* request)
: m_request(request),
  m_executed(false)
{
	m_time_stamp = om->jack_driver()->time_stamp();
}


} // namespace Om

